@@ -83,9 +83,9 @@ impl CondowClient for FsClient {
                         ));
                     }
 
-                    let mut buffer = Vec::with_capacity(n_bytes_to_read as usize);
+                    let mut buffer = vec![0; n_bytes_to_read as usize];
 
-                    let n_bytes_read = file.read(&mut buffer).await?;
+                    let n_bytes_read = file.read_exact(&mut buffer).await?;
 
                     if n_bytes_read as u64 != n_bytes_to_read {
                         return Err(CondowError::new_io(format!(
